@@ -5,8 +5,11 @@ from cyrusbus import Bus
 
 
 class Limiter(object):
-    def __init__(self):
+    def __init__(self, limiter_miss_timeout_ms=None):
         self.bus = Bus()
+        self.limiter_miss_timeout_ms = limiter_miss_timeout_ms
+        if self.limiter_miss_timeout_ms is None:
+            self.limiter_miss_timeout_ms = 500
 
     def handle_callbacks(self, callback):
         def handle(bus, *args, **kw):
